<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.System.RemoteSystems

Windows Runtime (WinRT) APIs for for the `Windows.System.RemoteSystems` namespace.

This package provides the `winrt.windows.system.remotesystems` module.
